@@ -193,6 +193,8 @@ pub struct Cache<K, V, S = RandomState> {
     value_initializer: Arc<ValueInitializer<K, V, S>>,
 }
 
+// TODO: https://github.com/moka-rs/moka/issues/54
+#[allow(clippy::non_send_fields_in_send_ty)]
 unsafe impl<K, V, S> Send for Cache<K, V, S>
 where
     K: Send + Sync,
@@ -354,7 +356,7 @@ where
     ///
     pub async fn get_or_insert_with<F>(&self, key: K, init: F) -> V
     where
-        F: Future<Output = V> + Send + 'static,
+        F: Future<Output = V>,
     {
         let hash = self.base.hash(&key);
         let key = Arc::new(key);
@@ -453,7 +455,7 @@ where
     ///
     pub async fn get_or_try_insert_with<F, E>(&self, key: K, init: F) -> Result<V, Arc<E>>
     where
-        F: Future<Output = Result<V, E>> + Send + 'static,
+        F: Future<Output = Result<V, E>>,
         E: Send + Sync + 'static,
     {
         let hash = self.base.hash(&key);
@@ -480,9 +482,7 @@ where
         let key = Arc::new(key);
         let op = self.base.do_insert_with_hash(key, hash, value);
         let hk = self.base.housekeeper.as_ref();
-        if Self::blocking_schedule_write_op(&self.base.write_op_ch, op, hk).is_err() {
-            panic!("Failed to insert");
-        }
+        Self::blocking_schedule_write_op(&self.base.write_op_ch, op, hk).expect("Failed to insert");
     }
 
     /// Discards any cached value for the key.
@@ -497,12 +497,9 @@ where
         if let Some(entry) = self.base.remove(key) {
             let op = WriteOp::Remove(entry);
             let hk = self.base.housekeeper.as_ref();
-            if Self::schedule_write_op(&self.base.write_op_ch, op, hk)
+            Self::schedule_write_op(&self.base.write_op_ch, op, hk)
                 .await
-                .is_err()
-            {
-                panic!("Failed to remove");
-            }
+                .expect("Failed to remove");
         }
     }
 
@@ -519,9 +516,8 @@ where
         if let Some(entry) = self.base.remove(key) {
             let op = WriteOp::Remove(entry);
             let hk = self.base.housekeeper.as_ref();
-            if Self::blocking_schedule_write_op(&self.base.write_op_ch, op, hk).is_err() {
-                panic!("Failed to remove");
-            }
+            Self::blocking_schedule_write_op(&self.base.write_op_ch, op, hk)
+                .expect("Failed to remove");
         }
     }
 
@@ -674,12 +670,9 @@ where
     async fn insert_with_hash(&self, key: Arc<K>, hash: u64, value: V) {
         let op = self.base.do_insert_with_hash(key, hash, value);
         let hk = self.base.housekeeper.as_ref();
-        if Self::schedule_write_op(&self.base.write_op_ch, op, hk)
+        Self::schedule_write_op(&self.base.write_op_ch, op, hk)
             .await
-            .is_err()
-        {
-            panic!("Failed to insert");
-        }
+            .expect("Failed to insert");
     }
 
     #[inline]
